CreateMergeRequestDiscussionNote

Struct CreateMergeRequestDiscussionNote 

pub struct CreateMergeRequestDiscussionNote {
    pub project: NameOrId<'static>,
    pub merge_request: u64,
    pub discussion_id: String,
    pub body: String,
}
Add a note (reply) to an existing merge request discussion.

Maps to POST /projects/:id/merge_requests/:merge_request/discussions/:discussion_id/notes.

Examples

use ironflow_ops_gitlab::GitLab;
use ironflow_ops_gitlab::endpoints::merge_requests::CreateMergeRequestDiscussionNote;
use gitlab::api::common::NameOrId;

let gitlab = GitLab::new("glpat-xxxx", "gitlab.com").await?;
let endpoint = CreateMergeRequestDiscussionNote {
    project: NameOrId::from(42),
    merge_request: 7,
    discussion_id: "abcd1234".to_string(),
    body: "Looks good, thanks!".to_string(),
};
let op = gitlab.op(endpoint);

Errors

Returns an error if the request fails or the response cannot be deserialized (e.g. the project, merge request or discussion does not exist).

Fields

project: NameOrId<'static>

The project the merge request belongs to.

merge_request: u64

The internal ID (iid) of the merge request.

discussion_id: String

The ID of the discussion thread to reply to.

body: String

The text of the note.